# Project Psion

This library provides an implementation for asynchronous authentication and authorization of web applications.
It provides support for OAuth 2.1 and OpenID Connect, as well as JOSE.

For more details, please visit the documentation.

Any doubts and suggestions can be sent to my [email](mailto:eduardorbr7@gmail.com).
Just prepend the title with #Psion#, and I will try my best to answer.

## JSON Object Signature and Encryption (JOSE)

It implements the following RFCs.

1. [x] RFC 7515 - Json Web Signature (JWS)
2. [ ] RFC 7516 - Json Web Encryption (JWE)
3. [x] RFC 7517 - Json Web Key and Keyset (JWK)
4. [x] RFC 7518 - Json Web Algorithms (JWA)
5. [x] RFC 7519 - Json Web Token (JWT)

For more details on each feature, please visit the respective documentation.

## OAuth 2.1

It implements the following RFCs and Specs.

1. [x] Draft - The OAuth 2.1 Authorization Framework
2. [x] RFC 7009 - OAuth 2.0 Token Revocation

# License

This project is licensed under the MIT License.
